@@ -135,6 +135,9 @@ namespace metaproxy_1 {
             // The following will be extracted from the configs above
             std::string proxyhost; // hpxy.indexdata.com
             std::string proxyprefix; // xxx/node102
+            std::vector< std::string> disableposttrick; // list of regexp strings.
+                         // If any match, the host-relative POST request trick
+                         // is not applied. See CPXY-89
         };
     }
 }
@@ -957,13 +960,29 @@ bool yf::CProxy::Rep::referer_trick(yf::CProxy::Handle &h,
     { // If not a GET request, we can not redirect, the browser will always
       // retry with a GET, loosing the POST data... So we try to set up the
       // handle for direct processing (CPXY-81)
-      h.cookiedb(std::string(hreq->method) + " request, can not redirect.  "
-        "Using url as is: " + url );
-      h.session = refsess;
-      h.targethost = refhost;
-      hreq->path = odr_strdup(h.odr,url.c_str());
-      return false; // signal we didn't redirect
-    }
+      
+        // Special case: CPXY-89: A host-relative POST does not always work,
+        // and may mess the page. So we have a list of regexps to disable the
+        // trick.
+        std::vector<std::string>::const_iterator sl;
+        std::string urlend = refhost + "/" + path;
+        for ( sl = disableposttrick.begin(); sl != disableposttrick.end(); sl++ )
+        {
+            boost::regex skipre( *sl, boost::regex::perl );
+            if ( boost::regex_search( urlend, skipre) )
+            {
+               h.db("Post-trick disabled. Url " + urlend + " matches " + *sl );
+               return false; // without setting session, etc. So we end up with a 400 no session
+            }
+        }
+
+        h.cookiedb(std::string(hreq->method) + " request, can not redirect.  "
+            "Using url as is: " + url );
+        h.session = refsess;
+        h.targethost = refhost;
+        hreq->path = odr_strdup(h.odr,url.c_str());
+        return false; // signal we didn't redirect
+    } // not GET
 
     
     // Set up a 302 - temporary redirect
@@ -1985,6 +2004,10 @@ void mp::filter::CProxy::configure(const xmlNode * ptr,
         {
             m_p->sessionmaxage = mp::xml::get_int(ptr,0);
         }
+        else if (!strcmp((const char *) ptr->name, "disableposttrick"))
+        {
+            m_p->disableposttrick.push_back( mp::xml::get_text(ptr) );
+        }
         else
         {
             throw mp::filter::FilterException
