@@ -431,6 +431,8 @@ void test1(void)
         "  <debug>1</debug>\n"    // gets enabled via the URL when needed
         "  <cfconfig>./cf-config.unittest.cfg</cfconfig>\n"
         "  <sessionmaxage>1</sessionmaxage>\n"
+        "  <disableposttrick>^disableposttrick.com/.*</disableposttrick>\n"
+        "  <disableposttrick>^.*/disableposttrick/</disableposttrick>\n"
         "</filter>\n";
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/node102",  // url prefix
@@ -689,6 +691,30 @@ void test1(void)
          "ref.host/ref.path/ref.to/ref.page.html");
     cpx->process(*pack);
     YAZ_CHECK( !check_response_code(pack, 302) );   // not a redirect!
+    delete(pack);
+
+    // Similar bad POST request, but to an address where we do not want to
+    // apply the test. CPXY-89
+    pack = make_package("http://localhost:9036/cproxydebug-nomove-verbose/"
+               "page.txt?param=value",1,"POST",content);
+    add_request_header(pack, "Referer",
+         "http://localhost:9036/XXX/node102/100/"
+         "disableposttrick.com/ref.path/ref.to/ref.page.html");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 400) );   // Bad req, no session
+    delete(pack);
+
+    // Same again, but with a different regexp. Also checks that we can loop
+    // through the pattern list.
+    pack = make_package("http://localhost:9036/cproxydebug-nomove-verbose/"
+               "foo.com/disableposttrick/page.txt?param=value",1,"POST",content);
+    add_request_header(pack, "Referer",
+         "http://localhost:9036/XXX/node102/100/"
+         "ref.host/ref.path/ref.to/ref.page.html");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 400) );   // Bad req, no session
+    delete(pack);
+
     
     remove_dump_dir("./cf.100.dump");
 
@@ -854,7 +880,7 @@ void test1(void)
     }
 
     delete(cpx);
-}
+} // test1
 
 
 ///////////////
